/*
                        OTF_NOTF_Query.js v0.3.7  by Eric Gerds

 - This script, together with PluginDetect and getJavaInfo.jar, is capable of doing
 both OTF and NOTF Java detection. 
 
 - NOTF detection can only be performed by this script if the PluginDetect script is
 generated with the "NOTF" checkbox enabled.

 - Java Detection is performed BEFORE the browser window has loaded.

 - Feel free to change this script, remove comments, etc... to fit your own needs.


 USAGE:
  1) Insert the PluginDetect script in the <head> of your HTML page:
        <script type="text/javascript" src="PluginDetect.js"></script>

  2) Insert the output <div> in the <body> of your HTML page. This div will receive the
     plugin detection results:
        <div id="javaresult"></div>

  3) If you wish to use the plugindetect <div>, then place it wherever you wish in the
     <body>. For example:
        <div id="plugindetect" style="right:0px; top:0px; position:absolute;"></div>

  4) This script starts doing detection as soon as it has loaded. Therefore, it should be placed
     AFTER the output <div> and after the plugindetect <div> (assuming you even specifed
     the plugindetect <div>). For example:
        <div id="javaresult"></div>
        <div id="plugindetect" style="right:0px; top:0px; position:absolute;"></div>
        <script type="text/javascript" src="OTF_NOTF_Query.js"></script>

  5) Get a copy of the "getJavaInfo.jar" jarfile and put it in the same folder as your
     HTML page.

     If you put the jarfile in a different directory than the HTML page, then
     you must adjust the path of the jarfile.
     The jarfile path is always relative to the web page.

     For example, say your web page is at http://www.mysite.com/webpage.htm
     and you have the jarfile at         http://www.mysite.com/stuff/getJavaInfo.jar
     then jarfile = "stuff/getJavaInfo.jar"

     If your web page is at      http://www.mysite.com/webpage.htm
     and you have the jarfile at http://www.mysite.com/getJavaInfo.jar
     then jarfile = "getJavaInfo.jar"


*/


// GLOBAL VARIABLES
var PD = PluginDetect;
var outputNode = 'javaresult';    // Id of output <div>. Detection results are placed in this div.


// The path of the jarfile is relative to the web page ( NOT relative to this
// external javascript file!!! ). Only the very first Java PluginDetect command that is executed
// needs to have the jarfile input argument. You do not have to specify this input arg in
// any subsequent Java PluginDetect commands.
var jarfile = '../Jarfiles/version3/getJavaInfo.jar';

// If the verifyTags input argument is not specified or is null, then PluginDetect assumes
// a default value of [2,2,2]. Only the very first Java PluginDetect command
// would need to have the verifyTags input argument, if at all. You do not have to specify 
// this input arg in any subsequent Java PluginDetect commands.
var verifyTags = [3,3,3];



function addText(node, text){
     var N = document.getElementById(node);
     if (N){
        N.appendChild(document.createTextNode(text));
        N.appendChild(document.createElement('br'));
     }
};



// This event handler sets the GLOBAL JAVA VARIABLES, and prints the results to the screen
function displayResults($){


  // Get extra info on the Java plugin.
  var INFO = $.getInfo ? $.getInfo('Java') : null;

  if (INFO && typeof INFO.vendor != 'undefined'){  // verify that INFO object has information


      var out, e, x, PLUGIN = INFO.PLUGIN, T =
          ['file.encoding', 'file.encoding.pkg', 'file.separator', 'java.class.path',
           'java.class.version', 'java.compiler', 'java.home', 'java.io.tmpdir',
           'java.version', 'java.vendor', 'java.vendor.url', 'user.dir', 'user.home',
           'java.vm.name', 'java.vm.specification.name', 'java.vm.specification.vendor',
           'java.vm.specification.version', 'java.vm.vendor', 'java.vm.version',
          'java.runtime.name', 'java.runtime.version', 'path.separator', 'java.specification.name',
           'java.specification.version', 'java.specification.vendor',
           'os.version', 'os.name', 'os.arch'];

      // Query instantiated Java applet to get extra info
      if (PLUGIN){
          addText(outputNode, "");
          addText(outputNode, "JAVA APPLET QUERY USING java.lang.System.getProperty(): ")
          for (x=0;x<T.length;x++){
             out=null;
             try{out = PLUGIN.getProp(T[x]) + " "}
             catch(e){};
             if (typeof out=='string' && out.length>1) addText(outputNode, T[x] + ": " + out);
          };
          addText(outputNode, "");
      };


  };



};  // end of displayResults()



PD.onDetectionDone('Java', displayResults, jarfile, verifyTags);




